@@ -1,15 +1,11 @@
-//! # Extension APIs for cap-std
-//!
-//! This crate builds on top of [`cap-std`].
-//!
-
 // See https://doc.rust-lang.org/rustc/lints/listing/allowed-by-default.html
 #![deny(missing_docs)]
+#![doc = include_str!("../README.md")]
 #![deny(missing_debug_implementations)]
 #![forbid(unused_must_use)]
 #![deny(unsafe_code)]
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
 
-/// Extension APIs for Command
 #[cfg(not(windows))]
 pub mod cmdext;
+pub mod dirext;
